==> restful-1.43.19-sources.jar: com/aote/rs/PathService.java <==
package com.aote.rs;

import com.af.plugins.AESUtil;
import com.af.plugins.RSAUtil;
import com.aote.path.PathMapper;
import com.aote.path.PathServer;
import com.aote.util.ExceptionHelper;
import com.aote.util.JsonHelper;
import com.aote.util.ParamFilter;
import com.aote.util.Util;
import org.apache.log4j.Logger;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;

/**
 * 提供path查询服务
 */
@Path("path")
@Component
@Transactional
public class PathService {
	static Logger log = Logger.getLogger(PathService.class);

	@Autowired
	private PathServer pathServer;

	/**
	 * 获取path查询的总数
	 * @param name path查询
	 * @param str 查询所需参数
	 * @return 总数
	 */
	@POST
	@Path("{name}/n")
	public String txgetTotalCnt(@PathParam("name") String name, String str)
			throws Exception {
		try {
			return pathEncrypt(name, str, false);
		} catch (Exception ex) {
			log.error(ExceptionHelper.stackToString(ex));
			throw ex;
		}
	}

	/**
	 * 执行path,对path中的参数进行替换 pageNo - 页号，默认为1 pageSize - 每页个数，默认为1000
	 */
	@POST
	@Path("{name}")
	public String txPath(@PathParam("name") String name,
						 @QueryParam("pageNo") int pageNo,
						 @QueryParam("pageSize") int pageSize, String str) throws Exception {
		try {
			String level = PathMapper.getAttr(name, "log");
			if (level != null) {
				log.info(name + ":" + str);
			}
			String ret = pathEncrypt(name, str, true, pageNo, pageSize);
			if (level != null) {
				log.info(name + ":" + ret);
			}
			return ret;
		} catch (Exception ex) {
			log.error(ExceptionHelper.stackToString(ex));
			throw ex;
		}
	}

	/**
	 * 封装path加解密
	 * @param pathName path名
	 * @param param	参数
	 * @param isQuery 区分调用
	 * @param values 接收分页的两个参数
	 * @return
	 * @throws Exception
	 */
	public String pathEncrypt(String pathName, String param, boolean isQuery, int ... values)throws Exception{
		JSONObject paramJson = new JSONObject(param);
		JSONObject configJson = JsonHelper.getConfig();
		//验证
		Util.checkEncry(paramJson, configJson);
		//如果不需要加密，进入default正常执行
		if (!paramJson.has("aoteEncrypt")){
			paramJson.put("aoteEncrypt", "default");
		}
		//sql注入标志位
		boolean sqlInject=false;
		if(configJson.has("sqlInject")){
			sqlInject = configJson.getBoolean("sqlInject");
		}
		//根据解密方式进行解密
		switch (paramJson.getString("aoteEncrypt")){
			case "AES" :
				// 数据解密
				String encryKey = configJson.getString("encryKey");
				String data = paramJson.getString("data");
				String decryData = AESUtil.decrypt(data, encryKey);
                //验证参数是否合法
				if(sqlInject) {
					ParamFilter.checkSqlJsonStr(decryData);
				}
				if (isQuery){
					return AESUtil.encrypt(pathServer.query(pathName, values[0], values[1], decryData).toString(), encryKey);
				}else{
					return AESUtil.encrypt(pathServer.queryTotal(pathName, decryData).toString(), encryKey);
				}
			default:
				//验证参数是否合法
				if(sqlInject) {
					ParamFilter.checkSqlJsonStr(param);
				}
				log.info("pathName:" + pathName + ", params:" + param);
				return isQuery ? pathServer.query(pathName, values[0], values[1], param).toString() : pathServer.queryTotal(pathName, param).toString();
		}
	}
}

==> restful-1.49.17-sources.jar: com/aote/rs/PathService.java <==
package com.aote.rs;

import com.aote.path.PathMapper;
import com.aote.path.PathServer;
import com.aote.util.ExceptionHelper;
import com.aote.util.JsonHelper;
import com.aote.util.ParamFilter;
import com.aote.util.Util;
import com.aote.util.other.AESUtil;
import org.apache.log4j.Logger;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;

/**
 * 提供path查询服务
 */
@Path("path")
@Component
@Transactional
public class PathService {
	static Logger log = Logger.getLogger(PathService.class);

	@Autowired
	private PathServer pathServer;

	/**
	 * 获取path查询的总数
	 * @param name path查询
	 * @param str 查询所需参数
	 * @return 总数
	 */
	@POST
	@Path("{name}/n")
	public String txgetTotalCnt(@PathParam("name") String name, String str)
			throws Exception {
		try {
			return pathEncrypt(name, str, false);
		} catch (Exception ex) {
			log.error(ExceptionHelper.stackToString(ex));
			throw ex;
		}
	}

	/**
	 * 执行path,对path中的参数进行替换 pageNo - 页号，默认为1 pageSize - 每页个数，默认为1000
	 */
	@POST
	@Path("{name}")
	public String txPath(@PathParam("name") String name,
						 @QueryParam("pageNo") int pageNo,
						 @QueryParam("pageSize") int pageSize, String str) throws Exception {
		try {
			String level = PathMapper.getAttr(name, "log");
			if (level != null) {
				log.info(name + ":" + str);
			}
			String ret = pathEncrypt(name, str, true, pageNo, pageSize);
			if (level != null) {
				log.info(name + ":" + ret);
			}
			return ret;
		} catch (Exception ex) {
			log.error(ExceptionHelper.stackToString(ex));
			throw ex;
		}
	}

	/**
	 * 封装path加解密
	 * @param pathName path名
	 * @param param	参数
	 * @param isQuery 区分调用
	 * @param values 接收分页的两个参数
	 * @return
	 * @throws Exception
	 */
	public String pathEncrypt(String pathName, String param, boolean isQuery, int ... values)throws Exception{
		JSONObject paramJson = new JSONObject(param);

		return AESUtil.encryptData(paramJson,
				(data) -> isQuery ? pathServer.query(pathName, values[0], values[1], data).toString() :
						pathServer.queryTotal(pathName, data).toString()
		);
	}
}
